@@ -8,6 +8,7 @@ import urllib
 from typing import List, Callable, Tuple
 from vessel.pipeline import Step, Payload
 from vessel.logging import logger
+from vessel.version import LATEST_AGENT, LATEST_SENTINEL
 
 class DeployAgentStep(Step):
   """
@@ -78,13 +79,13 @@ class GenerateYamlStep(Step):
     (name, rsa, vault_user, vault_pwd, distribution) = self._get_keys(payload)
 
     start_fn("generating sentinel yaml")
-    sentinel_yaml = self.sentinel_yaml(name=name, token=payload.token, vault_password=vault_pwd, distribution=distribution, tag='latest')
+    sentinel_yaml = self.sentinel_yaml(name=name, token=payload.token, vault_password=vault_pwd, distribution=distribution, tag=LATEST_SENTINEL)
     
     with open(f"{path}/sentinel.yaml", 'w') as f:
       f.write(sentinel_yaml)
 
     start_fn("generating agent yaml")
-    agent_yaml = self.agent_yaml(name=name, token=payload.token, rsa=rsa.replace("\n", "\\n"), tag='latest')
+    agent_yaml = self.agent_yaml(name=name, token=payload.token, rsa=rsa.replace("\n", "\\n"), tag=LATEST_AGENT)
    
     with open(f"{path}/agent.yaml", 'w') as f:
       f.write(agent_yaml)
@@ -198,7 +199,7 @@ class GenerateYamlStep(Step):
                         name: vault-secret
                         key: PWD
                   - name: ANCHORE_URL
-                    value: http://anchore-anchore-engine-api.anchore.svc:8228/anchore
+                    value: http://anchore-anchore-engine-api.anchore.svc:8228
                   - name: ANCHORE_USERNAME
                     value: admin
                   - name: ANCHORE_PWD
@@ -215,7 +216,7 @@ class GenerateYamlStep(Step):
           metadata:
             labels:
               app: {name}-sentinel
-            name: svc-{name}-sentinel
+            name: {name}-sentinel
           spec:
             ports:
             - name: 8089-tcp
@@ -236,7 +237,7 @@ class GenerateYamlStep(Step):
               http:
                 paths:
                 - backend:
-                    serviceName: svc-{name}-sentinel
+                    serviceName: {name}-sentinel
                     servicePort: 8089
                   path: /
         """
